@@ -32,6 +32,7 @@ AuthManager::AuthManager(QObject *parent) :
 {
     lastWindowsID = 0;
     adapter = NULL;
+    isProxySet = false;
 }
 
 
@@ -116,13 +117,41 @@ void AuthManager::setProxy(const QString &proxyIP, const QString &proxyPort,
         << " port = " << proxyPort.toAscii().constData()
         << " username = " << username.toAscii().constData()
         << " password = " << password.toAscii().constData() << ").";
+    isProxySet = true;
+
+    QString curProxy = proxyIP;
+    QString curPort = proxyPort;
 
     uint port = proxyPort.toUInt();
 
+    qDebug() << "port is " << port;
+
     if (proxyIP.isNull() == true || proxyIP.isEmpty() == true
            || port <= 0) {
-        qDebug() << "Proxy not set(incorrect host or port).";
-        return;
+
+	/* try to mannualy detect proxy settings */
+        QNetworkProxyQuery npq(QUrl(QLatin1String("http://maemo.org")));
+        QList<QNetworkProxy> proxyList = QNetworkProxyFactory::systemProxyForQuery(npq);
+        if (proxyList.length() > 0 && proxyList.at(0) != QNetworkProxy::NoProxy)
+        {
+    	    curProxy = proxyList.at(0).hostName();
+    	    curPort = proxyList.at(0).port();
+        } else {
+    	    QString var(getenv("http_proxy"));
+    	    if (var.isNull()) {
+		var = getenv("all_proxy");
+	    }
+            QRegExp regex("(http://)?(.*):(\\d*)/?");
+            int pos = regex.indexIn(var);
+
+            if(pos > -1) {
+        	curProxy = regex.cap(2);
+		curPort = regex.cap(3);
+	    } else {
+    		qDebug() << "Proxy not set(incorrect host or port).";
+    		return;
+	    }
+        }
     }
 
     if (username.isNull() != true
@@ -132,8 +161,11 @@ void AuthManager::setProxy(const QString &proxyIP, const QString &proxyPort,
     }
 
     proxy.setType(QNetworkProxy::HttpProxy);
-    proxy.setHostName(proxyIP);
-    proxy.setPort(port);
+    proxy.setHostName(curProxy);
+    proxy.setPort(curPort.toUInt());
+
+    qDebug() << "\nSetting proxy...(host = " << curProxy
+        << " port = " << curPort << ").";
 
     QNetworkProxy::setApplicationProxy(proxy);
 }
@@ -160,12 +192,16 @@ void AuthManager::shutdown()
 void AuthManager::auth(const QString &url)
 {
 
+    if (!isProxySet)
+	this->setProxy(QString::null, QString::null, QString::null, QString::null);
+
     qDebug() << "\nUsing simple auth...";
     ++lastWindowsID;
     MainWindow *mw = new MainWindow(lastWindowsID);
 
     windows.insert(lastWindowsID, mw);
     connect(mw, SIGNAL (closed(const int)), SLOT (windowsClosed(const int)));
+
     mw->startAuth(url);
 }
 
@@ -178,6 +214,9 @@ void AuthManager::auth(const QString &url)
  */
 void AuthManager::auth(const QString &url, const  QStringList &params)
 {
+    if (!isProxySet)
+	this->setProxy(QString::null, QString::null, QString::null, QString::null);
+
     qDebug() << "\nUsing extended auth...";
 
     ++lastWindowsID;
@@ -187,7 +226,6 @@ void AuthManager::auth(const QString &url, const  QStringList &params)
     connect(mw, SIGNAL (closed(const int)), SLOT (windowsClosed(const int)));
 
     mw->startAuth(url, params);
-
 }
 
 
@@ -211,5 +249,4 @@ void AuthManager::windowsClosed(const int windowID)
     if (windows.isEmpty() == true) {
         shutdown();
     }
-
 }
